@@ -19,7 +19,7 @@
 #include "ui_kaider_findextension.h"
 #include "stemming.h"
 
-
+#include <kcoreaddons_version.h>
 #include <klocalizedstring.h>
 #include <kmessagebox.h>
 #include <kreplacedialog.h>
@@ -47,7 +47,7 @@ static long makeOptions(long options, const Ui_findExtension* ui_findExtension)
 class EntryFindDialog: public KFindDialog
 {
 public:
-    EntryFindDialog(QWidget* parent);
+    explicit EntryFindDialog(QWidget* parent);
     ~EntryFindDialog();
     long options() const
     {
@@ -101,7 +101,7 @@ EntryFindDialog::~EntryFindDialog()
 class EntryReplaceDialog: public KReplaceDialog
 {
 public:
-    EntryReplaceDialog(QWidget* parent);
+    explicit EntryReplaceDialog(QWidget* parent);
     ~EntryReplaceDialog();
     long options() const
     {
@@ -160,13 +160,13 @@ static void calcOffsetWithAccels(const QString& data, int& offset, int& length)
 {
     int i = 0;
     for (; i < offset; ++i)
-        if (Q_UNLIKELY(data.at(i) == '&'))
+        if (Q_UNLIKELY(data.at(i) == QLatin1Char('&')))
             ++offset;
 
     //if & is inside highlighted word
     int limit = offset + length;
     for (i = offset; i < limit; ++i)
-        if (Q_UNLIKELY(data.at(i) == '&')) {
+        if (Q_UNLIKELY(data.at(i) == QLatin1Char('&'))) {
             ++length;
             limit = qMin(data.size(), offset + length); //just safety
         }
@@ -195,7 +195,7 @@ void EditorTab::find()
         if (sel.isEmpty())
             sel = selectionInSource();
         if (m_find && m_find->options()&IGNOREACCELS)
-            sel.remove('&');
+            sel.remove(QLatin1Char('&'));
         EntryFindDialog::instance()->setPattern(sel);
     }
 
@@ -209,8 +209,8 @@ void EditorTab::find()
 
     } else { // This creates a find-next-prompt dialog if needed.
         m_find = new KFind(EntryFindDialog::instance()->pattern(), EntryFindDialog::instance()->options(), this, EntryFindDialog::instance());
-        connect(m_find, QOverload<const QString &, int, int>::of(&KFind::highlight), this, &EditorTab::highlightFound);
-        connect(m_find, &KFind::findNext, this, QOverload<>::of(&EditorTab::findNext));
+        connect(m_find, &KFind::textFound, this, &EditorTab::highlightFound);
+        connect(m_find, &KFind::findNext, this, qOverload<>(&EditorTab::findNext));
         m_find->closeFindNextDialog();
     }
 
@@ -239,7 +239,7 @@ void EditorTab::findNext(const DocPosition& startingPos)
         _searchingPos.offset = 0;
 
 
-    QRegExp rx("[^(\\\\n)>]\n");
+    QRegExp rx(QStringLiteral("[^(\\\\n)>]\n"));
     //_searchingPos.part=DocPosition::Source;
     bool ignoreaccels = m_find->options()&IGNOREACCELS;
     bool includenotes = m_find->options()&INCLUDENOTES;
@@ -261,7 +261,7 @@ void EditorTab::findNext(const DocPosition& startingPos)
                     data = catalog.catalogString(_searchingPos).string;
 
                 if (ignoreaccels)
-                    data.remove('&');
+                    data.remove(QLatin1Char('&'));
                 find.setData(data);
             }
 
@@ -329,7 +329,7 @@ void EditorTab::replace()
     if (!m_view->selectionInTarget().isEmpty()) {
         if (m_replace && m_replace->options()&IGNOREACCELS) {
             QString tmp(m_view->selectionInTarget());
-            tmp.remove('&');
+            tmp.remove(QLatin1Char('&'));
             EntryReplaceDialog::instance()->setPattern(tmp);
         } else
             EntryReplaceDialog::instance()->setPattern(m_view->selectionInTarget());
@@ -345,9 +345,9 @@ void EditorTab::replace()
     // This creates a find-next-prompt dialog if needed.
     {
         m_replace = new KReplace(EntryReplaceDialog::instance()->pattern(), EntryReplaceDialog::instance()->replacement(), EntryReplaceDialog::instance()->options(), this, EntryReplaceDialog::instance());
-        connect(m_replace, QOverload<const QString &, int, int>::of(&KReplace::highlight), this, &EditorTab::highlightFound_);
-        connect(m_replace, &KReplace::findNext, this, QOverload<>::of(&EditorTab::replaceNext));
-        connect(m_replace, QOverload<const QString &, int, int, int>::of(&KReplace::replace), this, &EditorTab::doReplace);
+        connect(m_replace, &KReplace::textFound, this, &EditorTab::highlightFound_);
+        connect(m_replace, &KReplace::findNext, this, qOverload<>(&EditorTab::replaceNext));
+        connect(m_replace, &KReplace::textReplaced, this, &EditorTab::doReplace);
         connect(m_replace, &KReplace::dialogClosed, this, &EditorTab::cleanupReplace);
 //         _replace->closeReplaceNextDialog();
     }
@@ -389,7 +389,7 @@ void EditorTab::replaceNext(const DocPosition& startingPos)
     while (flag) {
         flag = 0;
         KFind::Result res = KFind::NoMatch;
-        while (1) {
+        while (true) {
             if (m_replace->needData() || anotherEntry/*||m_view->m_modifiedAfterFind*/) {
                 anotherEntry = false;
                 //m_view->m_modifiedAfterFind=false;//NOTE TEST THIS
@@ -399,7 +399,7 @@ void EditorTab::replaceNext(const DocPosition& startingPos)
                     data = m_catalog->notes(_replacingPos).at(_replacingPos.form).content;
                 else {
                     data = m_catalog->targetWithTags(_replacingPos).string;
-                    if (ignoreaccels) data.remove('&');
+                    if (ignoreaccels) data.remove(QLatin1Char('&'));
                 }
                 m_replace->setData(data);
             }
@@ -465,7 +465,7 @@ void EditorTab::doReplace(const QString &newStr, int offset, int newLen, int rem
     }
     DocPosition pos = _replacingPos;
     if (_replacingPos.part == DocPosition::Comment)
-        m_catalog->push(new SetNoteCmd(m_catalog, pos, newStr));
+        m_catalog->push(new SetNoteCmd(m_catalog, pos, Note(newStr)));
     else {
         QString oldStr = m_catalog->target(_replacingPos);
 
@@ -507,7 +507,7 @@ void EditorTab::spellcheck()
     QString text = m_catalog->msgstr(m_currentPos);
     if (!m_view->selectionInTarget().isEmpty())
         text = m_view->selectionInTarget();
-    text.remove('&');
+    text.remove(QLatin1Char('&'));
     m_sonnetDialog->setBuffer(text);
 
     _spellcheckPos = m_currentPos;
@@ -529,10 +529,21 @@ void EditorTab::spellcheckNext()
         if (!switchNext(m_catalog, _spellcheckPos)) {
             qCDebug(LOKALIZE_LOG) << _spellcheckStartPos.entry;
             qCDebug(LOKALIZE_LOG) << _spellcheckStartPos.form;
+#if KCOREADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+            bool continueFromStart =
+                    !(_spellcheckStartPos.entry == 0 && _spellcheckStartPos.form == 0)
+                    && KMessageBox::PrimaryAction == KMessageBox::questionTwoActions(
+                        this,
+                        i18n("Lokalize has reached end of document. Do you want to continue from start?"),
+                        i18nc("@title", "Spellcheck"),
+                        KStandardGuiItem::cont(),
+                        KStandardGuiItem::cancel());
+#else
             bool continueFromStart =
                 !(_spellcheckStartPos.entry == 0 && _spellcheckStartPos.form == 0)
                 && KMessageBox::questionYesNo(this, i18n("Lokalize has reached end of document. Do you want to continue from start?"),
                                               i18nc("@title", "Spellcheck")) == KMessageBox::Yes;
+#endif
             if (continueFromStart) {
                 _spellcheckStartPos.entry = 0;
                 _spellcheckStartPos.form = 0;
